@@ -1638,6 +1638,11 @@ bind .xcircuit.mainframe.mainarea.drawing <ButtonPress> {standardaction %b down
 bind .xcircuit.mainframe.mainarea.drawing <ButtonRelease> {standardaction %b up %s}
 bind .xcircuit.mainframe.mainarea.drawing <KeyPress> {standardaction %k key %s}
 
+# Here are some extra key functions that come with the TCL wrapper
+
+bind .xcircuit.mainframe.mainarea.drawing <Key-Next> {catch {page [expr {[page] + 1}]}}
+bind .xcircuit.mainframe.mainarea.drawing <Key-Prior> {catch {page [expr {[page] - 1}]}}
+
 # Wait for the drawing area to become visible, and set the focus on it.
 
 tkwait visibility .xcircuit.mainframe.mainarea.drawing
